@@ -179,6 +179,19 @@ class TestProcessObjectLeaks(TestMemLeak):
 
     proc = thisproc
 
+    def test_coverage(self):
+        skip = set((
+            "pid", "as_dict", "children", "cpu_affinity", "cpu_percent",
+            "ionice", "is_running", "kill", "memory_info_ex", "memory_percent",
+            "nice", "oneshot", "parent", "rlimit", "send_signal", "suspend",
+            "terminate", "wait"))
+        for name in dir(psutil.Process):
+            if name.startswith('_'):
+                continue
+            if name in skip:
+                continue
+            self.assertTrue(hasattr(self, "test_" + name), msg=name)
+
     @skip_if_linux()
     def test_name(self):
         self.execute(self.proc.name)
@@ -258,6 +271,10 @@ class TestProcessObjectLeaks(TestMemLeak):
     def test_num_fds(self):
         self.execute(self.proc.num_fds)
 
+    @skip_if_linux()
+    def test_num_ctx_switches(self):
+        self.execute(self.proc.num_ctx_switches)
+
     @skip_if_linux()
     def test_threads(self):
         self.execute(self.proc.threads)
@@ -266,6 +283,12 @@ class TestProcessObjectLeaks(TestMemLeak):
     def test_cpu_times(self):
         self.execute(self.proc.cpu_times)
 
+    @skip_if_linux()
+    @unittest.skipUnless(hasattr(psutil.Process, "cpu_num"),
+                         "platform not supported")
+    def test_cpu_num(self):
+        self.execute(self.proc.cpu_num)
+
     @skip_if_linux()
     def test_memory_info(self):
         self.execute(self.proc.memory_info)
@@ -437,6 +460,17 @@ class TestTerminatedProcessLeaks(TestProcessObjectLeaks):
 class TestModuleFunctionsLeaks(TestMemLeak):
     """Test leaks of psutil module functions."""
 
+    def test_coverage(self):
+        skip = set((
+            "version_info", "__version__", "process_iter", "wait_procs",
+            "cpu_percent", "cpu_times_percent", "cpu_count"))
+        for name in psutil.__all__:
+            if not name.islower():
+                continue
+            if name in skip:
+                continue
+            self.assertTrue(hasattr(self, "test_" + name), msg=name)
+
     # --- cpu
 
     @skip_if_linux()
@@ -458,6 +492,11 @@ class TestModuleFunctionsLeaks(TestMemLeak):
     def test_cpu_stats(self):
         self.execute(psutil.cpu_stats)
 
+    @skip_if_linux()
+    @unittest.skipUnless(hasattr(psutil, "cpu_freq"), "platform not supported")
+    def test_cpu_freq(self):
+        self.execute(psutil.cpu_freq)
+
     # --- mem
 
     def test_virtual_memory(self):
@@ -490,6 +529,12 @@ class TestModuleFunctionsLeaks(TestMemLeak):
     def test_disk_io_counters(self):
         self.execute(psutil.disk_io_counters)
 
+    # --- proc
+
+    @skip_if_linux()
+    def test_pids(self):
+        self.execute(psutil.pids)
+
     # --- net
 
     @skip_if_linux()
@@ -511,6 +556,26 @@ class TestModuleFunctionsLeaks(TestMemLeak):
     def test_net_if_stats(self):
         self.execute(psutil.net_if_stats)
 
+    # --- sensors
+
+    @unittest.skipUnless(hasattr(psutil, "sensors_battery"),
+                         "platform not supported")
+    @skip_if_linux()
+    def test_sensors_battery(self):
+        self.execute(psutil.sensors_battery)
+
+    @skip_if_linux()
+    @unittest.skipUnless(hasattr(psutil, "sensors_temperatures"),
+                         "platform not supported")
+    def test_sensors_temperatures(self):
+        self.execute(psutil.sensors_temperatures)
+
+    @unittest.skipUnless(hasattr(psutil, "sensors_fans"),
+                         "platform not supported")
+    @skip_if_linux()
+    def test_sensors_fans(self):
+        self.execute(psutil.sensors_fans)
+
     # --- others
 
     @skip_if_linux()
